#!/bin/ksh

WORKDIR=`dirname $0`
. $WORKDIR/setenv.sh

# show usage of the command
showusage()
{
echo "Usage:"
echo "------"
echo "off | more"
echo "migratedb.sh db2/oracle dbname userId password backupdir noatp/atp [hostname port | db2indir db2insthome] schemaowner (jvmheapsz)"
echo "for db2 with atp feature"
echo "migratedb.sh db2 mall db2inst1 db2inst1 /backup atp $DB2_HOME /home/db2inst1/sqllib DB2INST1 "
echo "for oracle with inventory compatibility mode and the database server"
echo "migratedb.sh oracle mall db2inst1 db2inst1 /backup noatp hostname port schemaowner"
echo "off | more"
echo "Note that the noatp/atp option is only applicable when you migrate from 5.1.0.1."
echo "When you migrate from other releases, we do not allow the inventory compatibility mode to be turned on or off."
echo "The atp/noatp option will actually be ignored whether you enter atp or noatp."
echo "JVM maximum heap size is optional. The default value is 128m"

exit 1
}


if [[ "x$1x" = "xx" ||  "x$2x" = "xx" ||  "x$3x" = "xx" || "x$4x" = "xx" || "x$5x" = "xx" || "x$6x" = "xx" ]]
then
     showusage
fi



if [[  "x$6x" = "xatpx" || "x$6x" = "xnoatpx" ]]
then

dbType=$1
database=$2
user=$3
password=$4
backupdir=$5
noatp=$6

if [[ $10 = "" ]];
then
	jvmheapsz=128m
else
	jvmheapsz=$10
fi

if [[ "x$1x" = "xdb2x" ]] ; then
schemaowner=$9
    . $8/db2profile
fi

if [[ ! -d $WCLOGDIR/migration ]];
then
       mkdir -p $WCLOGDIR/migration
fi

if [[ "x$1x" = "xoraclex" ]] ; then
       if [[ "x$7x" = "xx" ||  "x$8x" = "xx" ||  "x$9x" = "xx" ]]
       then
                   showusage
       fi
       hostname=$7
       port=$8
       schemaowner=$9
fi


schema=$WCS_HOME/schema
log=$WCLOGDIR/migration/migrate.log
. $WORKDIR/setdbenv.$dbType.sh
CPM=$WCS_HOME/properties:$WCS_HOME/lib/xml4j.jar:$WCS_HOME/lib/wcsmigration.jar:$CLASSPATH
migrategen=com.ibm.commerce.migration.tool.MigrateDBGen

${JAVA_EXE?} -classpath $CPM  $migrategen $dbType $database  $user $password $hostname $port >> $log 2>&1
echo "migratedb.$dbType.sh is generated."


Show_Log="Migration is completed, please look at the migratedb.log"
Migration_Home=$WCLOGDIR/migration
DB2_Migration=". $PWD/migratedb.$dbType.sh $database $user $password $backupdir $schemaowner"
Oracle_Migration=". $PWD/migratedb.$dbType.sh $database $user $password $hostname $port $backupdir $schemaowner"

if [[ "x$1x" = "xdb2x" ]] ; then

     echo "db2 database type"
       if [[ "x$7x" = "xx" || "x$8x" = "xx" ]] ; then
              showusage
              cd $Migration_Home
               echo  "$Show_Log"
              exit 1
       fi
       db2install=$7
       db2insthome=$8
       db2updv7 -d $database -u $user -p $password -n
       db2 terminate  
       db2 connect to $database user $user using $password
       db2 bind $db2install/bnd/@db2ubind.lst GRANT PUBLIC 
       db2 bind $db2insthome/bnd/@db2cli.lst  GRANT PUBLIC 
       db2 terminate 

     if [[ "x$6x" = "xnoatpx" ]] ; then
         echo "noatp"
         $DB2_Migration noatp $jvmheapsz >> $log 2>&1
         cd $Migration_Home
         echo  "$Show_Log"
         exit 1
     fi
           echo "atp"
            $DB2_Migration atp $jvmheapsz >> $log 2>&1
            cd $Migration_Home
            echo  "$Show_Log"

     exit 1
fi

echo "oracle database type"

if [[ "x$6x" = "xnoatpx" ]] ; then
     echo "noatp"
     $Oracle_Migration $noatp $jvmheapsz >> $log 2>&1
     cd $Migration_Home
     echo  "$Show_Log"

     exit 1
fi

$Oracle_Migration atp $jvmheapsz >> $log 2>&1
cd $Migration_Home
echo  "$Show_Log"

exit 1

fi




